import dbm
import argparse

import rss
import pleroma
from session import Session


def run():
    parser = argparse.ArgumentParser(prog='rss2pleroma')
    parser.add_argument('--db', required=True, help='path to database file')
    parser.add_argument('--rss_url', required=True, help='RSS URL, for example: https://example.net/feed.xml')
    parser.add_argument('--server_url', required=True, help='pleroma base URL, for example: https://pleroma.example')
    parser.add_argument('--token', required=True, help='user token (write:statuses write:media), details: https://docs.joinmastodon.org/client/authorized/#flow')
    parser.add_argument('--publish', action=argparse.BooleanOptionalAction)
    args = parser.parse_args()

    with dbm.open(args.db, 'c') as db:
        session = Session(args.server_url, args.token)
        def _publish(content, media):
            return pleroma.publish(session, content, media)
        processor = _publish if args.publish else lambda *_: '1'
        rss.process_new_items(db, args.rss_url, processor)
