import sys
import traceback
import requests
import xml.etree.ElementTree as ET

from hashlib import sha256


def process_new_items(db, url, fn):
    for item in reversed(list(_iterate_items(url))):
        # key = sha256((item.get('title') + item.get('link') + item.get('description')).encode()).digest()
        key = item.get('link')
        if not db.get(key):
            try:
                value = fn(item.format(), item.get_media())
            except:
                exc_type, exc_value, exc_traceback = sys.exc_info()
                traceback.print_exception(exc_type, exc_value, exc_traceback, file=sys.stdout)
                print(item)
            else:
                db[key] = value


def _get_raw(url):
    r = requests.get(url)
    r.raise_for_status()
    return r.text


class _Item(object):
    def __init__(self, elem):
        self._dict = {i.tag: i for i in elem}

    def get(self, name):
        child = self._dict.get(name)
        return (None if child is None else child.text) or ''

    def get_media(self):
        enclosure = self._dict.get('enclosure')
        return None if enclosure is None else enclosure.attrib.get('url')

    def format(self):
        link = self.get('link')
        if not link:
            return self.get('description')

        p = ET.Element('p')
        a = ET.SubElement(p, 'a')
        a.attrib.update(href=link)
        a.text = self.get('title') or link
        return ET.tostring(p, encoding="unicode") + self.get('description').strip()


def _iterate_items(url):
    for root_child in ET.fromstring(_get_raw(url)):
        if root_child.tag == 'channel':
            for channel_child in root_child:
                if channel_child.tag == 'item':
                    yield _Item(channel_child)
            break
